@@ -3,14 +3,15 @@
 
 #include <QDialog>
 
-namespace Ui {
+namespace Ui
+{
 class addnowDialog;
 }
 
 class addnowDialog : public QDialog
 {
     Q_OBJECT
-    
+
 public:
     //explicit
     addnowDialog(QWidget *parent = 0);
@@ -18,7 +19,7 @@ public:
     int getValue();
     QString getIntf();
     ~addnowDialog();
-    
+
 private:
     Ui::addnowDialog *ui;
 };
